@@ -3,6 +3,7 @@ import pywencai as wc
 import tushare as ts
 import os
 from kit import num_kit, path_kit
+import pathlib
 
 '''
 数据函数
@@ -190,13 +191,12 @@ class feature_data_loader:
     3.保存数据集
     """
 
-    def __init__(self, base_data=None, path="../data/", module="data/", file_name="feature_data.csv"):
+    def __init__(self, base_data=None, path="../data/", module="data/"):
         self.data = base_data
         self.features_list = []
         self.result = pd.DataFrame()
         self.path = path
         self.module = module
-        self.file_name = file_name
         self.module_path = path + module
 
     def add_feature(self, feature):
@@ -216,26 +216,17 @@ class feature_data_loader:
         """
         pass
 
-    def save(self, path=None, name=None):
-        """
-        保存数据集
-        :param name:
-        :param path:
-        :return:
-        """
-        file_path = self.module_path if path is None else path
-        file_name = self.file_name if name is None else name
-        self.result.to_csv(file_path + file_name, index=False, encoding='utf-8')
-
-    def execute(self):
+    def create_execute(self, path=None):
         """
         执行特征工程
         :return:
         """
+        file_path = self.module_path if path is None else path
+        path_kit.create_dir(file_path + "/feature")
         symbol_list = self.data['ts_code'].unique()
         columns = self.data.columns
-        for index,symbol in enumerate(symbol_list):
-            print("数据进度百分比:%s" % (index / len(symbol_list) * 100), end='\r', flush=True)
+        for index, symbol in enumerate(symbol_list):
+            print("数据进度百分比:%s" % (index / len(symbol_list) * 100))
             symbol_data = pd.DataFrame(self.data[self.data['ts_code'] == symbol])
             symbol_data.reset_index(drop=True, inplace=True)
             for func in self.features_list:
@@ -246,15 +237,36 @@ class feature_data_loader:
             symbol_data_right.applymap(lambda x: round(float(x), 2) if isinstance(x, (int, float)) else x)
             # 将新列数据集和旧列数据集合并
             data = pd.merge(symbol_data_left, symbol_data_right, left_index=True, right_index=True)
-            self.result = pd.concat([self.result, data])
+            data.to_csv(file_path + "/feature/" + symbol + ".csv", index=False, encoding='utf-8')
         return self.result
 
+    def to_execute(self, data, indicator):
+        """
+        执行特征工程
+        :return:
+        """
+        symbol_list = data['ts_code'].unique()
+        columns = data.columns
+        for index, symbol in enumerate(symbol_list):
+            print("数据进度百分比:%s" % (index / len(symbol_list) * 100))
+            symbol_data = pd.DataFrame(data[data['ts_code'] == symbol])
+            symbol_data.reset_index(drop=True, inplace=True)
+            for func in indicator:
+                func(symbol_data)
+            # 将symbol_data 按照旧列和新列分成2个数据集
+            symbol_data_left = symbol_data[columns]
+            symbol_data_right = symbol_data[symbol_data.columns[~symbol_data.columns.isin(symbol_data_left.columns)]]
+            symbol_data_right.applymap(lambda x: round(float(x), 2) if isinstance(x, (int, float)) else x)
+            # 将新列数据集和旧列数据集合并
+            data1 = pd.merge(symbol_data_left, symbol_data_right, left_index=True, right_index=True)
+        return data1
+
 
 # 训练测试工程
 class trains_data_loader:
 
-    def __init__(self, base_data=None, path="../data/", module="data/"):
-        self.base = base_data
+    def __init__(self, path="../data/", module="data/"):
+        self.feature_dir = None
         self.path = path
         self.module = module
         self.module_path = path + module
@@ -264,6 +276,9 @@ class trains_data_loader:
         self.test_y = pd.DataFrame()
         self.drop_column = []
 
+    def load_feature_dir(self, feature_dir):
+        self.feature_dir = feature_dir
+
     def drop_columns(self, columns):
         """
         删除指定列
@@ -273,34 +288,43 @@ class trains_data_loader:
         for column in columns:
             self.drop_column.append(column)
 
-    def train_split_by_time(self, start, end):
+    def split_by_time(self, trains_start, trains_end, test_start, test_end):
         """
+        :param test_end:
+        :param test_start:
+        :param trains_end:
+        :param trains_start:
+        :param trans:
         :param start:
         :param end:
         :return:
         """
-        self.train_X = self.base[(self.base['trade_date'] > start) & (self.base['trade_date'] < end)]
-        self.train_X = self.train_X.drop(self.drop_column, axis=1)
-        self.train_y = self.base[(self.base['trade_date'] > start) & (self.base['trade_date'] < end)]
-        self.train_y = self.train_y['flag']
-        return self.train_X, self.train_y
+        self.train_X = pd.DataFrame()
+        self.train_y = pd.DataFrame()
+        self.test_X = pd.DataFrame()
+        self.test_y = pd.DataFrame()
+        file_list = os.listdir(self.module_path + self.feature_dir)
+        for index, file in enumerate(file_list):
+            print(f"读取进度:{(index / len(file_list)) * 100}")
+            data = pd.read_csv(self.module_path + self.feature_dir + file)
 
-    def test_split_by_time(self, start, end):
-        """
-        :param start:
-        :param end:
-        :return:
-        """
-        self.test_X = self.base[(self.base['trade_date'] > start) & (self.base['trade_date'] < end)]
-        self.test_X = self.test_X.drop(self.drop_column, axis=1)
-        self.test_y = self.base[(self.base['trade_date'] > start) & (self.base['trade_date'] < end)]
-        self.test_y = self.test_y['flag']
-        return self.test_X, self.test_y
+            trains_x = data[(data['trade_date'] > trains_start) & (data['trade_date'] < trains_end)]
+            trains_y = trains_x['flag']
+            trains_x = trains_x.drop(self.drop_column, axis=1)
+            self.train_X = pd.concat([self.train_X, trains_x])
+            self.train_y = pd.concat([self.train_y, trains_y])
+
+            test_X = data[(data['trade_date'] > test_start) & (data['trade_date'] < test_end)]
+            test_y = test_X['flag']
+            test_X = test_X.drop(self.drop_column, axis=1)
+            self.test_X = pd.concat([self.test_X, test_X])
+            self.test_y = pd.concat([self.test_y, test_y])
 
     def obverse(self, mlflow):
-        mlflow.log_metric("train_label_1", len(self.train_X[self.train_X['flag'] == 1]) / len(self.train_X) * 100)
-        mlflow.log_metric("train_label_0", len(self.train_X[self.train_X['flag'] == 1]) / len(self.train_X) * 100)
-        mlflow.log_metric("train_label_-1", len(self.train_X[self.train_X['flag'] == 1]) / len(self.train_X) * 100)
+        pass
+        # mlflow.log_metric("train_label_1", len(self.train_X[self.train_X['flag'] == 1]) / len(self.train_X) * 100)
+        # mlflow.log_metric("train_label_0", len(self.train_X[self.train_X['flag'] == 1]) / len(self.train_X) * 100)
+        # mlflow.log_metric("train_label_-1", len(self.train_X[self.train_X['flag'] == 1]) / len(self.train_X) * 100)
 
     def save(self, path=None):
         """
@@ -308,11 +332,12 @@ class trains_data_loader:
         :param path:
         :return:
         """
+
         file_path = self.module_path if path is None else path
-        self.train_X.to_csv(file_path + 'train_X.csv', index=False, encoding='utf-8')
-        self.train_y.to_csv(file_path + 'train_y.csv', index=False, encoding='utf-8')
-        self.test_X.to_csv(file_path + 'test_X.csv', index=False, encoding='utf-8')
-        self.test_y.to_csv(file_path + 'test_y.csv', index=False, encoding='utf-8')
+        self.train_X.to_pickle(file_path + 'train_X.pkl')
+        self.train_y.to_pickle(file_path + 'train_y.pkl')
+        self.test_X.to_pickle(file_path + 'test_X.pkl')
+        self.test_y.to_pickle(file_path + 'test_y.pkl')
 
 
 class backtrader_data_loader:
